import os
from robot.api import logger

import jsonschema
import json


class JSONSchemaLibrary(object):
    ROBOT_LIBRARY_SCOPE = 'Global'

    def __init__(self, schema_location='schemas'):
        self._schema_location = schema_location
        if not self._schema_location.endswith('/'):
            self._schema_location = '{}/'.format(self._schema_location)

    def validate_json(self, schema_path, data):
        schema = self._load_schema(schema_path)
        try:
            jsonschema.validate(data, schema)
        except jsonschema.ValidationError as e:
            logger.debug(e)
            err_msg = 'Validation error for schema {}: {}'.format(
                schema_path, e.message)
            raise jsonschema.ValidationError(err_msg)

    def _load_schema(self, schema_path):
        if os.path.isfile(schema_path):
            schema_file = schema_path
        else:
            schema_file = '{}/{}'.format(self._schema_location, schema_path)
            if not os.path.isfile(schema_file):
                raise FileNotFoundError(
                    'Schema file not found: {}'.format(schema_path))
        schema = json.loads(open(schema_file).read())
        return schema



import os
from setuptools import setup, find_packages

VERSION = '0.1.0'
PATH = os.path.dirname(os.path.abspath(__file__))

install_requires = [
    'robotframework',
    'jsonschema',
]


def read(fname):
    return open(os.path.join(PATH, fname)).read()


setup(
    name='robot-jsonschemalibrary',
    version=VERSION,
    description='A Robot Framework library for JSON Schema validation.',
    long_description=read('README.rst'),
    url='https://github.com/hypc/robot-jsonschemalibrary',
    author='hypc',
    author_email='h_yp00@163.com',
    license='MIT',
    keywords='robotframework json jsonschema',
    packages=find_packages(exclude=['docs', 'tests*', 'example']),
    install_requires=install_requires,
    python_requires='>=3',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Framework :: Robot Framework',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)
